<?php

namespace Litecms\Onboardchecklist\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Onboardchecklist\Models\Checklist;

class ChecklistPolicy
{

    /**
     * Determine if the given user can view the checklist.
     *
     * @param UserPolicy $user
     * @param Checklist $checklist
     *
     * @return bool
     */
    public function view(UserPolicy $user, Checklist $checklist)
    {
        if ($user->canDo('onboardchecklist.checklist.view') && $user->isAdmin()) {
            return true;
        }

        return $checklist->user_id == user_id() && $checklist->user_type == user_type();
    }

    /**
     * Determine if the given user can create a checklist.
     *
     * @param UserPolicy $user
     * @param Checklist $checklist
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('onboardchecklist.checklist.create');
    }

    /**
     * Determine if the given user can update the given checklist.
     *
     * @param UserPolicy $user
     * @param Checklist $checklist
     *
     * @return bool
     */
    public function update(UserPolicy $user, Checklist $checklist)
    {
        if ($user->canDo('onboardchecklist.checklist.edit') && $user->isAdmin()) {
            return true;
        }

        return $checklist->user_id == user_id() && $checklist->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given checklist.
     *
     * @param UserPolicy $user
     * @param Checklist $checklist
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Checklist $checklist)
    {
        return $checklist->user_id == user_id() && $checklist->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given checklist.
     *
     * @param UserPolicy $user
     * @param Checklist $checklist
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Checklist $checklist)
    {
        if ($user->canDo('onboardchecklist.checklist.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given checklist.
     *
     * @param UserPolicy $user
     * @param Checklist $checklist
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Checklist $checklist)
    {
        if ($user->canDo('onboardchecklist.checklist.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
