<?php

namespace Litecms\Onboardchecklist\Providers;

use Illuminate\Support\ServiceProvider;

class OnboardchecklistServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'onboardchecklist');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'onboardchecklist');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerOnboardchecklist();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerOnboardchecklist()
    {
        $this->app->bind('onboardchecklist', function($app) {
            return new Onboardchecklist($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Onboardchecklist', 'Lavalite\Onboardchecklist\Facades\Onboardchecklist');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('litecms.onboardchecklist', function ($app) {
            return $this->app->make('Litecms\Onboardchecklist\Onboardchecklist');
        });

                // Bind Checklist to repository
        $this->app->bind(
            'Litecms\Onboardchecklist\Interfaces\ChecklistRepositoryInterface',
            \Litecms\Onboardchecklist\Repositories\Eloquent\ChecklistRepository::class
        );

        $this->app->register(\Litecms\Onboardchecklist\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\Onboardchecklist\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and onboardchecklist's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/onboardchecklist.php', 'onboardchecklist'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeOnboardchecklist::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.onboardchecklist'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/onboardchecklist.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/onboardchecklist')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/onboardchecklist')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
